{pkgs, ...}: {
  home.stateVersion = "23.05";
  imports = [
    ../modules/home-manager/emails.nix
    ../modules/home-manager/dotfiles.nix
    ../modules/home-manager/tmux.nix
  ];
  home.sessionVariables = {
    EDITOR = "nvim";
  };
  home.sessionPath = [
    "$HOME/Code/nixos-config/scripts"
    "$HOME/.local/bin"
    "$HOME/go/bin"
  ];

  programs = {
    direnv = {
      enable = true;
      enableZshIntegration = true;
      nix-direnv.enable = true;
    };

    git = {
      enable = true;
      userName = "Florian Schmitt";
      userEmail = "mrflos@gmail.com";
      aliases = {
        fa = "fetch --all --tags --prune --recurse-submodules --force";
      };
      extraConfig = {
        pull.rebase = true;
        init.defaultBranch = "main";
        core.editor = "nvim";
        core.fileMode = false;
      };
    };
    mpv = {
      enable = true;
      package = (
        pkgs.mpv-unwrapped.wrapper {
          scripts = with pkgs.mpvScripts; [
            mpris
            sponsorblock
            thumbfast
            #uosc
            #modernx
            mpv-osc-tethys
            visualizer
          ];

          mpv = pkgs.mpv-unwrapped.override {
            waylandSupport = true;
          };
        }
      );

      config = {
        profile = "high-quality";
        ytdl-format = "bestvideo+bestaudio";
      };
    };
    neovim = {
      defaultEditor = true;
      viAlias = true;
      vimAlias = true;
    };

    starship = {
      enable = true;
      settings = with builtins; fromTOML (readFile ../dotfiles/starship/starship.toml);
    };

    thunderbird = {
      enable = true;
      profiles."mrflos" = {
        isDefault = true;
      };
    };
    zsh = {
      enable = true;
      autosuggestion.enable = true;
      enableCompletion = true;
      shellAliases = {
        #tmux = "tmux -f ~/.config/tmux/tmux.conf attach || tmux -f ~/.config/tmux/tmux.conf new";
        bunx = "bun --bun x";
        c = "$HOME/Code/nixos-config/scripts/tmux-sessionizer";
        g = "lazygit";
        n = "$HOME/Code/nixos-config/scripts/open-notes";
        s = "$HOME/Code/nixos-config/scripts/ssh-connect";
        t = "$HOME/Code/nixos-config/scripts/tmux-sessionizer";
        kdenix = "nix run github:pjones/plasma-manager --extra-experimental-features nix-command --extra-experimental-features flakes > $HOME/Developpements/nixos-config/modules/home-plasma.nix";
        icat = "kitty +kitten icat";
        nixedit = "nvim $HOME/Code/nixos-config/";
        nixupdate = "nix-channel --update && home-manager switch -b backup";
        nixclean = "nix-store --gc";
        socks = "ssh -N -f -C -D 9090 mrflos@yunohost.yeswiki.net -p 6742";
        vi = "$HOME/.nix-profile/bin/nvim";
        vim = "$HOME/.nix-profile/bin/nvim";
        yeswiki-updater = "cd $HOME/Code/yeswiki-installer/ && sudo php yeswiki-updater.php";
      };
      initContent = ''
        export BUN_INSTALL="$HOME/.bun"
        export PHP_CS_FIXER_IGNORE_ENV=1
        export PATH="$HOME/.local/bin:$BUN_INSTALL/bin:$PATH"
        eval "$(atuin init zsh)"
        eval "$(zoxide init zsh)"
      '';
      oh-my-zsh = {
        enable = true;
        extraConfig = ''
          zstyle :omz:plugins:ssh-agent helper ksshaskpass
          zstyle :omz:plugins:ssh-agent agent-forwarding yes
          zstyle :omz:plugins:ssh-agent lazy yes
        '';
        plugins = [
          "git"
          "ssh-agent"
        ];
      };
    };
  };
  services.ssh-agent.enable = true;
}
